@@ -30,20 +30,20 @@ G_BEGIN_DECLS
  * The flags to show daemon status.
  **/
 typedef enum {
-	FWUPD_STATUS_UNKNOWN,				/* Since: 0.1.1 */
-	FWUPD_STATUS_IDLE,				/* Since: 0.1.1 */
-	FWUPD_STATUS_LOADING,				/* Since: 0.1.1 */
-	FWUPD_STATUS_DECOMPRESSING,			/* Since: 0.1.1 */
-	FWUPD_STATUS_DEVICE_RESTART,			/* Since: 0.1.1 */
-	FWUPD_STATUS_DEVICE_WRITE,			/* Since: 0.1.1 */
-	FWUPD_STATUS_DEVICE_VERIFY,			/* Since: 0.1.1 */
-	FWUPD_STATUS_SCHEDULING,			/* Since: 0.1.1 */
-	FWUPD_STATUS_DOWNLOADING,			/* Since: 0.9.4 */
-	FWUPD_STATUS_DEVICE_READ,			/* Since: 1.0.0 */
-	FWUPD_STATUS_DEVICE_ERASE,			/* Since: 1.0.0 */
-	FWUPD_STATUS_WAITING_FOR_AUTH,			/* Since: 1.0.0 */
-	FWUPD_STATUS_DEVICE_BUSY,			/* Since: 1.0.1 */
-	FWUPD_STATUS_SHUTDOWN,				/* Since: 1.2.1 */
+	FWUPD_STATUS_UNKNOWN,	       /* Since: 0.1.1 */
+	FWUPD_STATUS_IDLE,	       /* Since: 0.1.1 */
+	FWUPD_STATUS_LOADING,	       /* Since: 0.1.1 */
+	FWUPD_STATUS_DECOMPRESSING,    /* Since: 0.1.1 */
+	FWUPD_STATUS_DEVICE_RESTART,   /* Since: 0.1.1 */
+	FWUPD_STATUS_DEVICE_WRITE,     /* Since: 0.1.1 */
+	FWUPD_STATUS_DEVICE_VERIFY,    /* Since: 0.1.1 */
+	FWUPD_STATUS_SCHEDULING,       /* Since: 0.1.1 */
+	FWUPD_STATUS_DOWNLOADING,      /* Since: 0.9.4 */
+	FWUPD_STATUS_DEVICE_READ,      /* Since: 1.0.0 */
+	FWUPD_STATUS_DEVICE_ERASE,     /* Since: 1.0.0 */
+	FWUPD_STATUS_WAITING_FOR_AUTH, /* Since: 1.0.0 */
+	FWUPD_STATUS_DEVICE_BUSY,      /* Since: 1.0.1 */
+	FWUPD_STATUS_SHUTDOWN,	       /* Since: 1.2.1 */
 	/*< private >*/
 	FWUPD_STATUS_LAST
 } FwupdStatus;
@@ -57,9 +57,9 @@ typedef enum {
  * The flags to show the level of trust.
  **/
 typedef enum {
-	FWUPD_TRUST_FLAG_NONE		= 0,		/* Since: 0.1.2 */
-	FWUPD_TRUST_FLAG_PAYLOAD	= 1 << 0,	/* Since: 0.1.2 */
-	FWUPD_TRUST_FLAG_METADATA	= 1 << 1,	/* Since: 0.1.2 */
+	FWUPD_TRUST_FLAG_NONE = 0,	    /* Since: 0.1.2 */
+	FWUPD_TRUST_FLAG_PAYLOAD = 1 << 0,  /* Since: 0.1.2 */
+	FWUPD_TRUST_FLAG_METADATA = 1 << 1, /* Since: 0.1.2 */
 	/*< private >*/
 	FWUPD_TRUST_FLAG_LAST
 } FwupdTrustFlags;
@@ -71,15 +71,21 @@ typedef enum {
  * @FWUPD_FEATURE_FLAG_DETACH_ACTION:		Can perform detach action, typically showing text
  * @FWUPD_FEATURE_FLAG_UPDATE_ACTION:		Can perform update action, typically showing text
  * @FWUPD_FEATURE_FLAG_SWITCH_BRANCH:		Can switch the firmware branch
+ * @FWUPD_FEATURE_FLAG_REQUESTS:		Can show interactive requests
+ * @FWUPD_FEATURE_FLAG_FDE_WARNING:		Can warn about full disk encryption
+ * @FWUPD_FEATURE_FLAG_COMMUNITY_TEXT:		Can show information about community supported
  *
  * The flags to the feature capabilities of the front-end client.
  **/
 typedef enum {
-	FWUPD_FEATURE_FLAG_NONE			= 0,		/* Since: 1.4.5 */
-	FWUPD_FEATURE_FLAG_CAN_REPORT		= 1 << 0,	/* Since: 1.4.5 */
-	FWUPD_FEATURE_FLAG_DETACH_ACTION	= 1 << 1,	/* Since: 1.4.5 */
-	FWUPD_FEATURE_FLAG_UPDATE_ACTION	= 1 << 2,	/* Since: 1.4.5 */
-	FWUPD_FEATURE_FLAG_SWITCH_BRANCH	= 1 << 3,	/* Since: 1.5.0 */
+	FWUPD_FEATURE_FLAG_NONE = 0,		    /* Since: 1.4.5 */
+	FWUPD_FEATURE_FLAG_CAN_REPORT = 1 << 0,	    /* Since: 1.4.5 */
+	FWUPD_FEATURE_FLAG_DETACH_ACTION = 1 << 1,  /* Since: 1.4.5 */
+	FWUPD_FEATURE_FLAG_UPDATE_ACTION = 1 << 2,  /* Since: 1.4.5 */
+	FWUPD_FEATURE_FLAG_SWITCH_BRANCH = 1 << 3,  /* Since: 1.5.0 */
+	FWUPD_FEATURE_FLAG_REQUESTS = 1 << 4,	    /* Since: 1.6.2 */
+	FWUPD_FEATURE_FLAG_FDE_WARNING = 1 << 5,    /* Since: 1.7.1 */
+	FWUPD_FEATURE_FLAG_COMMUNITY_TEXT = 1 << 6, /* Since: 1.7.5 */
 	/*< private >*/
 	FWUPD_FEATURE_FLAG_LAST
 } FwupdFeatureFlags;
@@ -91,7 +97,7 @@ typedef enum {
  *
  * Since 0.1.3
  */
-#define FWUPD_DEVICE_FLAG_NONE			(0u)
+#define FWUPD_DEVICE_FLAG_NONE (0u)
 /**
  * FWUPD_DEVICE_FLAG_INTERNAL:
  *
@@ -99,7 +105,7 @@ typedef enum {
  *
  * Since 0.1.3
  */
-#define FWUPD_DEVICE_FLAG_INTERNAL		(1u << 0)
+#define FWUPD_DEVICE_FLAG_INTERNAL (1u << 0)
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE:
  *
@@ -107,7 +113,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_UPDATABLE		(1u << 1)
+#define FWUPD_DEVICE_FLAG_UPDATABLE (1u << 1)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_OFFLINE:
  *
@@ -115,7 +121,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE		(1u << 2)
+#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE (1u << 2)
 /**
  * FWUPD_DEVICE_FLAG_REQUIRE_AC:
  *
@@ -124,7 +130,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_REQUIRE_AC		(1u << 3)
+#define FWUPD_DEVICE_FLAG_REQUIRE_AC (1u << 3)
 /**
  * FWUPD_DEVICE_FLAG_LOCKED:
  *
@@ -132,7 +138,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_LOCKED		(1u << 4)
+#define FWUPD_DEVICE_FLAG_LOCKED (1u << 4)
 /**
  * FWUPD_DEVICE_FLAG_SUPPORTED:
  *
@@ -140,7 +146,7 @@ typedef enum {
  *
  * Since 0.7.1
  */
-#define FWUPD_DEVICE_FLAG_SUPPORTED		(1u << 5)
+#define FWUPD_DEVICE_FLAG_SUPPORTED (1u << 5)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER:
  *
@@ -148,7 +154,7 @@ typedef enum {
  *
  * Since 0.7.3
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER	(1u << 6)
+#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER (1u << 6)
 /**
  * FWUPD_DEVICE_FLAG_REGISTERED:
  *
@@ -156,7 +162,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_REGISTERED		(1u << 7)
+#define FWUPD_DEVICE_FLAG_REGISTERED (1u << 7)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_REBOOT:
  *
@@ -164,7 +170,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT		(1u << 8)
+#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT (1u << 8)
 /**
  * FWUPD_DEVICE_FLAG_REPORTED:
  *
@@ -172,7 +178,7 @@ typedef enum {
  *
  * Since: 1.0.4
  */
-#define FWUPD_DEVICE_FLAG_REPORTED		(1u << 9)
+#define FWUPD_DEVICE_FLAG_REPORTED (1u << 9)
 /**
  * FWUPD_DEVICE_FLAG_NOTIFIED:
  *
@@ -180,7 +186,7 @@ typedef enum {
  *
  * Since: 1.0.5
  */
-#define FWUPD_DEVICE_FLAG_NOTIFIED		(1u << 10)
+#define FWUPD_DEVICE_FLAG_NOTIFIED (1u << 10)
 /**
  * FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION:
  *
@@ -188,7 +194,7 @@ typedef enum {
  *
  * Since: 1.0.6
  */
-#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION	(1u << 11)
+#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION (1u << 11)
 /**
  * FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST:
  *
@@ -197,7 +203,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST	(1u << 12)
+#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST (1u << 12)
 /**
  * FWUPD_DEVICE_FLAG_IS_BOOTLOADER:
  *
@@ -205,7 +211,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER		(1u << 13)
+#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER (1u << 13)
 /**
  * FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG:
  *
@@ -213,7 +219,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG	(1u << 14)
+#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG (1u << 14)
 /**
  * FWUPD_DEVICE_FLAG_IGNORE_VALIDATION:
  *
@@ -221,7 +227,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION	(1u << 15)
+#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION (1u << 15)
 /**
  * FWUPD_DEVICE_FLAG_TRUSTED:
  *
@@ -230,7 +236,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_TRUSTED		(1u << 16)
+#define FWUPD_DEVICE_FLAG_TRUSTED (1u << 16)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN:
  *
@@ -238,7 +244,7 @@ typedef enum {
  *
  * Since: 1.2.4
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN	(1u << 17)
+#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN (1u << 17)
 /**
  * FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED:
  *
@@ -255,7 +261,7 @@ typedef enum {
  * Since: 1.2.5
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS	(1u << 19)
+#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS (1u << 19)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION:
  *
@@ -265,7 +271,7 @@ typedef enum {
  *
  * Since: 1.2.6
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION	(1u << 20)
+#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION (1u << 20)
 /**
  * FWUPD_DEVICE_FLAG_ENSURE_SEMVER:
  *
@@ -274,7 +280,7 @@ typedef enum {
  * Since: 1.2.9
  * Deprecate: 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER		(1u << 21)
+#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER (1u << 21)
 /**
  * FWUPD_DEVICE_FLAG_HISTORICAL:
  *
@@ -282,7 +288,7 @@ typedef enum {
  *
  * Since: 1.3.2
  */
-#define FWUPD_DEVICE_FLAG_HISTORICAL		(1u << 22)
+#define FWUPD_DEVICE_FLAG_HISTORICAL (1u << 22)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_SUPPORTED:
  *
@@ -291,7 +297,7 @@ typedef enum {
  * Since: 1.3.3
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED	(1u << 23)
+#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED (1u << 23)
 /**
  * FWUPD_DEVICE_FLAG_WILL_DISAPPEAR:
  *
@@ -300,15 +306,15 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR	(1u << 24)
+#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR (1u << 24)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY:
  *
- * THe device checksums can be compared against metadata.
+ * The device checksums can be compared against metadata.
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY		(1u << 25)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY (1u << 25)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE:
  *
@@ -316,7 +322,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE	(1u << 26)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE (1u << 26)
 /**
  * FWUPD_DEVICE_FLAG_DUAL_IMAGE:
  *
@@ -325,7 +331,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_DUAL_IMAGE		(1u << 27)
+#define FWUPD_DEVICE_FLAG_DUAL_IMAGE (1u << 27)
 /**
  * FWUPD_DEVICE_FLAG_SELF_RECOVERY:
  *
@@ -334,7 +340,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_SELF_RECOVERY		(1u << 28)
+#define FWUPD_DEVICE_FLAG_SELF_RECOVERY (1u << 28)
 /**
  * FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE:
  *
@@ -343,7 +349,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE	(1u << 29)
+#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE (1u << 29)
 /**
  * FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED:
  *
@@ -359,7 +365,7 @@ typedef enum {
  *
  * Since: 1.3.7
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES	(1u << 31)
+#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES (1u << 31)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_NAME:
  *
@@ -368,7 +374,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_NAME		(1llu << 32)
+#define FWUPD_DEVICE_FLAG_MD_SET_NAME (1llu << 32)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY:
  *
@@ -377,7 +383,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY	(1llu << 33)
+#define FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY (1llu << 33)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_VERFMT:
  *
@@ -386,7 +392,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_VERFMT		(1llu << 34)
+#define FWUPD_DEVICE_FLAG_MD_SET_VERFMT (1llu << 34)
 /**
  * FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS:
  *
@@ -395,7 +401,7 @@ typedef enum {
  *
  * Since: 1.4.0
  */
-#define FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS	(1llu << 35)
+#define FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS (1llu << 35)
 /**
  * FWUPD_DEVICE_FLAG_NO_GUID_MATCHING:
  *
@@ -404,7 +410,7 @@ typedef enum {
  * Since: 1.4.1
  * Deprecated 1.5.8
  */
-#define FWUPD_DEVICE_FLAG_NO_GUID_MATCHING	(1llu << 36)
+#define FWUPD_DEVICE_FLAG_NO_GUID_MATCHING (1llu << 36)
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN:
  *
@@ -413,7 +419,7 @@ typedef enum {
  *
  * Since: 1.4.1
  */
-#define FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN	(1llu << 37)
+#define FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN (1llu << 37)
 /**
  * FWUPD_DEVICE_FLAG_SKIPS_RESTART:
  *
@@ -421,7 +427,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_SKIPS_RESTART		(1llu << 38)
+#define FWUPD_DEVICE_FLAG_SKIPS_RESTART (1llu << 38)
 /**
  * FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES:
  *
@@ -429,7 +435,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES	(1llu << 39)
+#define FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES (1llu << 39)
 /**
  * FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL:
  *
@@ -437,16 +443,86 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL	(1llu << 40)
+#define FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL (1llu << 40)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_ICON:
  *
- *Deprecated, no not use
+ * Deprecated, no not use
  *
  * Since: 1.5.2
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_ICON		(1llu << 41)
+#define FWUPD_DEVICE_FLAG_MD_SET_ICON (1llu << 41)
+/**
+ * FWUPD_DEVICE_FLAG_WILDCARD_INSTALL:
+ *
+ * All devices with matching GUIDs will be updated at the same time.
+ *
+ * For some devices it is not possible to have different versions of firmware
+ * for hardware of the same type. Updating one device will force update of
+ * others with exactly the same instance IDs.
+ *
+ * Since: 1.6.2
+ */
+#define FWUPD_DEVICE_FLAG_WILDCARD_INSTALL (1llu << 42)
+/**
+ * FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE:
+ *
+ * The device firmware can only be updated to a newer version and never downgraded or reinstalled.
+ *
+ * Since 1.6.2
+ */
+#define FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE (1llu << 43)
+/**
+ * FWUPD_DEVICE_FLAG_UNREACHABLE:
+ *
+ * The device is currently unreachable, perhaps because it is in a lower power state or is out of
+ * wireless range.
+ *
+ * Since 1.7.0
+ */
+#define FWUPD_DEVICE_FLAG_UNREACHABLE (1llu << 44)
+/**
+ * FWUPD_DEVICE_FLAG_AFFECTS_FDE:
+ *
+ * The device is warning that a volume with full-disk-encryption was found on this machine,
+ * typically a Windows NTFS partition with BitLocker.
+ * Updating the firmware on this device may invalidate secrets used to decrypt the volume, and
+ * the recovery key may be required.
+ *
+ * Supported clients will display this information as a warning to the user.
+ *
+ * Since: 1.7.1
+ */
+#define FWUPD_DEVICE_FLAG_AFFECTS_FDE (1llu << 45)
+/**
+ * FWUPD_DEVICE_FLAG_END_OF_LIFE:
+ *
+ * The device is no longer supported by the original hardware vendor as it is considered
+ * end-of-life. It it unlikely to receive firmware updates, even for security issues.
+ *
+ * Since: 1.7.5
+ */
+#define FWUPD_DEVICE_FLAG_END_OF_LIFE (1llu << 46)
+/**
+ * FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD:
+ *
+ * The firmware payload is verified on-device the payload using strong cryptography such
+ * as RSA, AES or ECC.
+ *
+ * It is usually not possible to modify or flash custom firmware not provided by the vendor.
+ *
+ * Since: 1.7.6
+ */
+#define FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD (1llu << 47)
+/**
+ * FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD:
+ *
+ * The firmware payload is unsigned and it is possible to modify and flash custom firmware.
+ *
+ * Since: 1.7.6
+ */
+#define FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD (1llu << 48)
 /**
  * FWUPD_DEVICE_FLAG_UNKNOWN:
  *
@@ -455,7 +531,7 @@ typedef enum {
  *
  * Since 0.7.3
  */
-#define FWUPD_DEVICE_FLAG_UNKNOWN		G_MAXUINT64
+#define FWUPD_DEVICE_FLAG_UNKNOWN G_MAXUINT64
 /**
  * FwupdDeviceFlags:
  *
@@ -470,7 +546,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_NONE			(0u)
+#define FWUPD_RELEASE_FLAG_NONE (0u)
 /**
  * FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD:
  *
@@ -478,7 +554,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD	(1u << 0)
+#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD (1u << 0)
 /**
  * FWUPD_RELEASE_FLAG_TRUSTED_METADATA:
  *
@@ -486,7 +562,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA	(1u << 1)
+#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA (1u << 1)
 /**
  * FWUPD_RELEASE_FLAG_IS_UPGRADE:
  *
@@ -494,7 +570,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_UPGRADE		(1u << 2)
+#define FWUPD_RELEASE_FLAG_IS_UPGRADE (1u << 2)
 /**
  * FWUPD_RELEASE_FLAG_IS_DOWNGRADE:
  *
@@ -502,7 +578,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE		(1u << 3)
+#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE (1u << 3)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_VERSION:
  *
@@ -510,7 +586,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION	(1u << 4)
+#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION (1u << 4)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL:
  *
@@ -518,7 +594,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL	(1u << 5)
+#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL (1u << 5)
 /**
  * FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH:
  *
@@ -526,7 +602,15 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.5.0
  */
-#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH	(1u << 6)
+#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH (1u << 6)
+/**
+ * FWUPD_RELEASE_FLAG_IS_COMMUNITY:
+ *
+ * The release is supported by the community and not the hardware vendor.
+ *
+ * Since: 1.7.5
+ */
+#define FWUPD_RELEASE_FLAG_IS_COMMUNITY (1u << 7)
 /**
  * FWUPD_RELEASE_FLAG_UNKNOWN:
  *
@@ -534,7 +618,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_UNKNOWN		G_MAXUINT64
+#define FWUPD_RELEASE_FLAG_UNKNOWN G_MAXUINT64
 /**
  * FwupdReleaseFlags:
  *
@@ -553,11 +637,11 @@ typedef guint64 FwupdReleaseFlags;
  * The release urgency.
  **/
 typedef enum {
-	FWUPD_RELEASE_URGENCY_UNKNOWN,				/* Since: 1.4.0 */
-	FWUPD_RELEASE_URGENCY_LOW,				/* Since: 1.4.0 */
-	FWUPD_RELEASE_URGENCY_MEDIUM,				/* Since: 1.4.0 */
-	FWUPD_RELEASE_URGENCY_HIGH,				/* Since: 1.4.0 */
-	FWUPD_RELEASE_URGENCY_CRITICAL,				/* Since: 1.4.0 */
+	FWUPD_RELEASE_URGENCY_UNKNOWN,	/* Since: 1.4.0 */
+	FWUPD_RELEASE_URGENCY_LOW,	/* Since: 1.4.0 */
+	FWUPD_RELEASE_URGENCY_MEDIUM,	/* Since: 1.4.0 */
+	FWUPD_RELEASE_URGENCY_HIGH,	/* Since: 1.4.0 */
+	FWUPD_RELEASE_URGENCY_CRITICAL, /* Since: 1.4.0 */
 	/*< private >*/
 	FWUPD_RELEASE_URGENCY_LAST
 } FwupdReleaseUrgency;
@@ -569,7 +653,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_NONE			(0u)
+#define FWUPD_PLUGIN_FLAG_NONE (0u)
 /**
  * FWUPD_PLUGIN_FLAG_DISABLED:
  *
@@ -577,7 +661,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_DISABLED		(1u << 0)
+#define FWUPD_PLUGIN_FLAG_DISABLED (1u << 0)
 /**
  * FWUPD_PLUGIN_FLAG_USER_WARNING:
  *
@@ -585,7 +669,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_USER_WARNING		(1u << 1)
+#define FWUPD_PLUGIN_FLAG_USER_WARNING (1u << 1)
 /**
  * FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE:
  *
@@ -594,7 +678,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE	(1u << 2)
+#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE (1u << 2)
 /**
  * FWUPD_PLUGIN_FLAG_NO_HARDWARE:
  *
@@ -604,7 +688,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_NO_HARDWARE		(1u << 3)
+#define FWUPD_PLUGIN_FLAG_NO_HARDWARE (1u << 3)
 /**
  * FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED:
  *
@@ -613,7 +697,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED	(1u << 4)
+#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED (1u << 4)
 /**
  * FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED:
  *
@@ -622,7 +706,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED	(1u << 5)
+#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED (1u << 5)
 /**
  * FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED:
  *
@@ -631,7 +715,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED	(1u << 6)
+#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED (1u << 6)
 /**
  * FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND:
  *
@@ -640,7 +724,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND		(1u << 7)
+#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND (1u << 7)
 /**
  * FWUPD_PLUGIN_FLAG_LEGACY_BIOS:
  *
@@ -649,7 +733,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS		(1u << 8)
+#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS (1u << 8)
 /**
  * FWUPD_PLUGIN_FLAG_FAILED_OPEN:
  *
@@ -658,7 +742,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_FAILED_OPEN		(1u << 9)
+#define FWUPD_PLUGIN_FLAG_FAILED_OPEN (1u << 9)
 /**
  * FWUPD_PLUGIN_FLAG_REQUIRE_HWID:
  *
@@ -666,7 +750,24 @@ typedef enum {
  *
  * Since: 1.5.8
  */
-#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID		(1u << 10)
+#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID (1u << 10)
+/**
+ * FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD:
+ *
+ * The feature is not supported as the kernel is too old.
+ *
+ * Since: 1.6.2
+ */
+#define FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD (1u << 11)
+/**
+ * FWUPD_PLUGIN_FLAG_AUTH_REQUIRED:
+ *
+ * The plugin requires the user to provide authentication details.
+ * Supported clients will display this information to a user.
+ *
+ * Since: 1.6.2
+ */
+#define FWUPD_PLUGIN_FLAG_AUTH_REQUIRED (1u << 12)
 /**
  * FWUPD_PLUGIN_FLAG_UNKNOWN:
  *
@@ -675,12 +776,12 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_UNKNOWN		G_MAXUINT64
- /**
-  * FwupdPluginFlags:
-  *
-  * Flags used to represent plugin attributes
-  */
+#define FWUPD_PLUGIN_FLAG_UNKNOWN G_MAXUINT64
+/**
+ * FwupdPluginFlags:
+ *
+ * Flags used to represent plugin attributes
+ */
 typedef guint64 FwupdPluginFlags;
 
 /**
@@ -695,22 +796,23 @@ typedef guint64 FwupdPluginFlags;
  * @FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM:		Ignore firmware CRCs and checksums
  * @FWUPD_INSTALL_FLAG_IGNORE_VID_PID:		Ignore firmware vendor and project checks
  * @FWUPD_INSTALL_FLAG_IGNORE_POWER:		Ignore requirement of external power source
+ *(Deprecated since 1.7.0)
  * @FWUPD_INSTALL_FLAG_NO_SEARCH:		Do not use heuristics when parsing the image
  *
  * Flags to set when performing the firmware update or install.
  **/
 typedef enum {
-	FWUPD_INSTALL_FLAG_NONE			= 0,		/* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_OFFLINE		= 1 << 0,	/* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL	= 1 << 1,	/* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_OLDER		= 1 << 2,	/* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_FORCE		= 1 << 3,	/* Since: 0.7.1 */
-	FWUPD_INSTALL_FLAG_NO_HISTORY		= 1 << 4,	/* Since: 1.0.8 */
-	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH	= 1 << 5,	/* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM	= 1 << 6,	/* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_VID_PID	= 1 << 7,	/* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_POWER		= 1 << 8,	/* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_NO_SEARCH		= 1 << 9,	/* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NONE = 0,			 /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_OFFLINE = 1 << 0,		 /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL = 1 << 1,	 /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_OLDER = 1 << 2,	 /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_FORCE = 1 << 3,		 /* Since: 0.7.1 */
+	FWUPD_INSTALL_FLAG_NO_HISTORY = 1 << 4,		 /* Since: 1.0.8 */
+	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH = 1 << 5, /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM = 1 << 6,	 /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_VID_PID = 1 << 7,	 /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_POWER = 1 << 8,	 /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NO_SEARCH = 1 << 9,		 /* Since: 1.5.0 */
 	/*< private >*/
 	FWUPD_INSTALL_FLAG_LAST
 } FwupdInstallFlags;
@@ -724,9 +826,9 @@ typedef enum {
  * Flags to set when performing the firmware update or install.
  **/
 typedef enum {
-	FWUPD_SELF_SIGN_FLAG_NONE		= 0,		/* Since: 1.2.6 */
-	FWUPD_SELF_SIGN_FLAG_ADD_TIMESTAMP	= 1 << 0,	/* Since: 1.2.6 */
-	FWUPD_SELF_SIGN_FLAG_ADD_CERT		= 1 << 1,	/* Since: 1.2.6 */
+	FWUPD_SELF_SIGN_FLAG_NONE = 0,		     /* Since: 1.2.6 */
+	FWUPD_SELF_SIGN_FLAG_ADD_TIMESTAMP = 1 << 0, /* Since: 1.2.6 */
+	FWUPD_SELF_SIGN_FLAG_ADD_CERT = 1 << 1,	     /* Since: 1.2.6 */
 	/*< private >*/
 	FWUPD_SELF_SIGN_FLAG_LAST
 } FwupdSelfSignFlags;
@@ -738,17 +840,18 @@ typedef enum {
  * @FWUPD_UPDATE_STATE_SUCCESS:			Update was successful
  * @FWUPD_UPDATE_STATE_FAILED:			Update failed
  * @FWUPD_UPDATE_STATE_NEEDS_REBOOT:		Waiting for a reboot to apply
- * @FWUPD_UPDATE_STATE_FAILED_TRANSIENT:	Update failed due to transient issue, e.g. AC power required
+ * @FWUPD_UPDATE_STATE_FAILED_TRANSIENT:	Update failed due to transient issue, e.g. AC power
+ *required
  *
  * The update state.
  **/
 typedef enum {
-	FWUPD_UPDATE_STATE_UNKNOWN,			/* Since: 0.7.0 */
-	FWUPD_UPDATE_STATE_PENDING,			/* Since: 0.7.0 */
-	FWUPD_UPDATE_STATE_SUCCESS,			/* Since: 0.7.0 */
-	FWUPD_UPDATE_STATE_FAILED,			/* Since: 0.7.0 */
-	FWUPD_UPDATE_STATE_NEEDS_REBOOT,		/* Since: 1.0.4 */
-	FWUPD_UPDATE_STATE_FAILED_TRANSIENT,		/* Since: 1.2.7 */
+	FWUPD_UPDATE_STATE_UNKNOWN,	     /* Since: 0.7.0 */
+	FWUPD_UPDATE_STATE_PENDING,	     /* Since: 0.7.0 */
+	FWUPD_UPDATE_STATE_SUCCESS,	     /* Since: 0.7.0 */
+	FWUPD_UPDATE_STATE_FAILED,	     /* Since: 0.7.0 */
+	FWUPD_UPDATE_STATE_NEEDS_REBOOT,     /* Since: 1.0.4 */
+	FWUPD_UPDATE_STATE_FAILED_TRANSIENT, /* Since: 1.2.7 */
 	/*< private >*/
 	FWUPD_UPDATE_STATE_LAST
 } FwupdUpdateState;
@@ -764,11 +867,11 @@ typedef enum {
  * The update state.
  **/
 typedef enum {
-	FWUPD_KEYRING_KIND_UNKNOWN,			/* Since: 0.9.7 */
-	FWUPD_KEYRING_KIND_NONE,			/* Since: 0.9.7 */
-	FWUPD_KEYRING_KIND_GPG,				/* Since: 0.9.7 */
-	FWUPD_KEYRING_KIND_PKCS7,			/* Since: 0.9.7 */
-	FWUPD_KEYRING_KIND_JCAT,			/* Since: 1.4.0 */
+	FWUPD_KEYRING_KIND_UNKNOWN, /* Since: 0.9.7 */
+	FWUPD_KEYRING_KIND_NONE,    /* Since: 0.9.7 */
+	FWUPD_KEYRING_KIND_GPG,	    /* Since: 0.9.7 */
+	FWUPD_KEYRING_KIND_PKCS7,   /* Since: 0.9.7 */
+	FWUPD_KEYRING_KIND_JCAT,    /* Since: 1.4.0 */
 	/*< private >*/
 	FWUPD_KEYRING_KIND_LAST
 } FwupdKeyringKind;
@@ -795,42 +898,62 @@ typedef enum {
  * be used to signify an unparsable text string.
  **/
 typedef enum {
-	FWUPD_VERSION_FORMAT_UNKNOWN,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_PLAIN,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_NUMBER,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_PAIR,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_TRIPLET,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_QUAD,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_BCD,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_INTEL_ME,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_INTEL_ME2,			/* Since: 1.2.9 */
-	FWUPD_VERSION_FORMAT_SURFACE_LEGACY,		/* Since: 1.3.4 */
-	FWUPD_VERSION_FORMAT_SURFACE,			/* Since: 1.3.4 */
-	FWUPD_VERSION_FORMAT_DELL_BIOS,			/* Since: 1.3.6 */
-	FWUPD_VERSION_FORMAT_HEX,		/* Since: 1.4.0 */
+	FWUPD_VERSION_FORMAT_UNKNOWN,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_PLAIN,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_NUMBER,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_PAIR,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_TRIPLET,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_QUAD,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_BCD,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_INTEL_ME,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_INTEL_ME2,	     /* Since: 1.2.9 */
+	FWUPD_VERSION_FORMAT_SURFACE_LEGACY, /* Since: 1.3.4 */
+	FWUPD_VERSION_FORMAT_SURFACE,	     /* Since: 1.3.4 */
+	FWUPD_VERSION_FORMAT_DELL_BIOS,	     /* Since: 1.3.6 */
+	FWUPD_VERSION_FORMAT_HEX,	     /* Since: 1.4.0 */
 	/*< private >*/
 	FWUPD_VERSION_FORMAT_LAST
 } FwupdVersionFormat;
 
-const gchar	*fwupd_status_to_string			(FwupdStatus	 status);
-FwupdStatus	 fwupd_status_from_string		(const gchar	*status);
-const gchar	*fwupd_device_flag_to_string		(FwupdDeviceFlags device_flag);
-FwupdDeviceFlags fwupd_device_flag_from_string		(const gchar	*device_flag);
-const gchar	*fwupd_plugin_flag_to_string		(FwupdPluginFlags plugin_flag);
-FwupdPluginFlags fwupd_plugin_flag_from_string		(const gchar	*plugin_flag);
-const gchar	*fwupd_release_flag_to_string		(FwupdReleaseFlags release_flag);
-FwupdReleaseFlags fwupd_release_flag_from_string	(const gchar	*release_flag);
-const gchar	*fwupd_release_urgency_to_string	(FwupdReleaseUrgency release_urgency);
-FwupdReleaseUrgency fwupd_release_urgency_from_string	(const gchar	*release_urgency);
-const gchar	*fwupd_update_state_to_string		(FwupdUpdateState update_state);
-FwupdUpdateState fwupd_update_state_from_string		(const gchar	*update_state);
-const gchar	*fwupd_trust_flag_to_string		(FwupdTrustFlags trust_flag);
-FwupdTrustFlags	 fwupd_trust_flag_from_string		(const gchar	*trust_flag);
-const gchar	*fwupd_feature_flag_to_string		(FwupdFeatureFlags feature_flag);
-FwupdFeatureFlags fwupd_feature_flag_from_string	(const gchar	*feature_flag);
-FwupdKeyringKind fwupd_keyring_kind_from_string		(const gchar	*keyring_kind);
-const gchar	*fwupd_keyring_kind_to_string		(FwupdKeyringKind keyring_kind);
-FwupdVersionFormat fwupd_version_format_from_string	(const gchar	*str);
-const gchar	*fwupd_version_format_to_string		(FwupdVersionFormat kind);
+const gchar *
+fwupd_status_to_string(FwupdStatus status);
+FwupdStatus
+fwupd_status_from_string(const gchar *status);
+const gchar *
+fwupd_device_flag_to_string(FwupdDeviceFlags device_flag);
+FwupdDeviceFlags
+fwupd_device_flag_from_string(const gchar *device_flag);
+const gchar *
+fwupd_plugin_flag_to_string(FwupdPluginFlags plugin_flag);
+FwupdPluginFlags
+fwupd_plugin_flag_from_string(const gchar *plugin_flag);
+const gchar *
+fwupd_release_flag_to_string(FwupdReleaseFlags release_flag);
+FwupdReleaseFlags
+fwupd_release_flag_from_string(const gchar *release_flag);
+const gchar *
+fwupd_release_urgency_to_string(FwupdReleaseUrgency release_urgency);
+FwupdReleaseUrgency
+fwupd_release_urgency_from_string(const gchar *release_urgency);
+const gchar *
+fwupd_update_state_to_string(FwupdUpdateState update_state);
+FwupdUpdateState
+fwupd_update_state_from_string(const gchar *update_state);
+const gchar *
+fwupd_trust_flag_to_string(FwupdTrustFlags trust_flag);
+FwupdTrustFlags
+fwupd_trust_flag_from_string(const gchar *trust_flag);
+const gchar *
+fwupd_feature_flag_to_string(FwupdFeatureFlags feature_flag);
+FwupdFeatureFlags
+fwupd_feature_flag_from_string(const gchar *feature_flag);
+FwupdKeyringKind
+fwupd_keyring_kind_from_string(const gchar *keyring_kind);
+const gchar *
+fwupd_keyring_kind_to_string(FwupdKeyringKind keyring_kind);
+FwupdVersionFormat
+fwupd_version_format_from_string(const gchar *str);
+const gchar *
+fwupd_version_format_to_string(FwupdVersionFormat kind);
 
 G_END_DECLS
