@@ -6,44 +6,34 @@
 
 #pragma once
 
-/**
- * SECTION:fwupd-version
- * @short_description: Obtains the version for the installed fwupd
- *
- * These compile time macros allow the user to enable parts of client code
- * depending on the version of libfwupd installed.
- */
+#include <glib.h>
 
-#if !defined (__FWUPD_H_INSIDE__) && !defined (FWUPD_COMPILATION)
+#if !defined(__FWUPD_H_INSIDE__) && !defined(FWUPD_COMPILATION)
 #error "Only <fwupd.h> can be included directly."
 #endif
 
+/* clang-format off */
 /**
  * FWUPD_MAJOR_VERSION:
  *
  * The compile-time major version
  */
-#ifndef FWUPD_MAJOR_VERSION
-#define FWUPD_MAJOR_VERSION				(1)
-#endif
+#define FWUPD_MAJOR_VERSION 1
 
 /**
  * FWUPD_MINOR_VERSION:
  *
  * The compile-time minor version
  */
-#ifndef FWUPD_MINOR_VERSION
-#define FWUPD_MINOR_VERSION				(6)
-#endif
+#define FWUPD_MINOR_VERSION 8
 
 /**
  * FWUPD_MICRO_VERSION:
  *
  * The compile-time micro version
  */
-#ifndef FWUPD_MICRO_VERSION
-#define FWUPD_MICRO_VERSION				(0)
-#endif
+#define FWUPD_MICRO_VERSION 0
+/* clang-format on */
 
 /**
  * FWUPD_CHECK_VERSION:
@@ -53,9 +43,15 @@
  *
  * Check whether a fwupd version equal to or greater than
  * major.minor.micro.
+ *
+ * These compile time macros allow the user to enable parts of client code
+ * depending on the version of libfwupd installed.
  */
-#define FWUPD_CHECK_VERSION(major,minor,micro)    \
-    (FWUPD_MAJOR_VERSION > (major) || \
-     (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION > (minor)) || \
-     (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION == (minor) && \
-      FWUPD_MICRO_VERSION >= (micro)))
+#define FWUPD_CHECK_VERSION(major, minor, micro)                                                   \
+	(FWUPD_MAJOR_VERSION > major ||                                                            \
+	 (FWUPD_MAJOR_VERSION == major && FWUPD_MINOR_VERSION > minor) ||                          \
+	 (FWUPD_MAJOR_VERSION == major && FWUPD_MINOR_VERSION == minor &&                          \
+	  FWUPD_MICRO_VERSION >= micro))
+
+const gchar *
+fwupd_version_string(void);
