@@ -3,6 +3,7 @@
 """A simple fwupd frontend"""
 import sys
 import os
+import dbus
 import gi
 from gi.repository import GLib
 
@@ -75,7 +76,7 @@ def parse_args():
 def refresh(client):
     """Uses fwupd client to refresh metadata"""
     remotes = client.get_remotes()
-    client.set_user_agent_for_package("simple_client", "1.6.0")
+    client.set_user_agent_for_package("simple_client", "1.8.0")
     for remote in remotes:
         if not remote.get_enabled():
             continue
@@ -110,6 +111,16 @@ def device_changed(client, device, progress):  # pylint: disable=unused-argument
     progress.device_changed(device.get_name())
 
 
+def modify_config(client, key, value):
+    """Use fwupd client to modify daemon configuration value"""
+    try:
+        print("setting configuration key %s to %s" % (key, value))
+        client.modify_config(key, value, None)
+    except Exception as e:
+        print("%s" % str(e))
+        sys.exit(1)
+
+
 def install(client, cab, target, older, reinstall):
     """Use fwupd client to install CAB file to applicable devices"""
     # FWUPD_DEVICE_ID_ANY
@@ -134,6 +145,25 @@ def install(client, cab, target, older, reinstall):
     print("\n")
 
 
+def get_daemon_property(key: str):
+    try:
+        bus = dbus.SystemBus()
+        proxy = bus.get_object(bus_name="org.freedesktop.fwupd", object_path="/")
+        iface = dbus.Interface(proxy, "org.freedesktop.DBus.Properties")
+        val = iface.Get("org.freedesktop.fwupd", key)
+        if isinstance(val, dbus.Boolean):
+            print(
+                "org.freedesktop.fwupd property %s, current value is %s"
+                % (key, bool(val))
+            )
+        else:
+            print("org.freedesktop.fwupd property %s, current value is %s" % (key, val))
+        return val
+    except dbus.DBusException as e:
+        print(e)
+    return None
+
+
 def check_exists(cab):
     """Check that CAB file exists"""
     if not cab:
@@ -147,7 +177,6 @@ def check_exists(cab):
 if __name__ == "__main__":
     ARGS = parse_args()
     CLIENT = Fwupd.Client()
-    CLIENT.connect()
 
     if ARGS.command == "get-devices":
         get_devices(CLIENT)
